---------------------------------------------------------------
--                                                           
--  RAPID - Rapid Ada Portable Interface Designer     
--                                                           
--  COMMON_DIALOGS.ADS 
--  Description : Implementation of Common Dialogs in Tcl/Tk
--                       
--  By: Martin Carlisle
--                                         
-- RAPID is free software; you can redistribute it and/or 
-- modify it without restriction.  However, we ask that you
-- please retain the original author information, and clearly  
-- indicate if it has been modified.
--
-- RAPID is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
--
---------------------------------------------------------------
with Tcl;

package Common_Dialogs is
   -- Display message and wait for user to press "OK"
   procedure Ok_Box(Message : in String; Interp : Tcl.Tcl_Interp;
      Parent_Window : in String := ".");

   -- ask a yes or no question
   function Yesno_Dialog(Interp : in Tcl.Tcl_Interp;
      Message : in String;
      Title   : in String;
      Parent_Window : in String := ".") return Boolean;

   -- Ask user if they want to quit if verify is true, then quit.  
   -- O/W, just quit.
   procedure Quit_Dialog(Interp : Tcl.Tcl_Interp; Verify : Boolean := True);

   -- Ask user for filename to open
   -- File_Types should look like :
   --   { "Tcl_Files" { .tcl .tk } }
   --   { "All Files" * }
   procedure Open_Dialog(Interp : Tcl.Tcl_Interp;
      File_Types : in String;
      Filename   : out String;
      File_Last  : out Natural;
      Title      : in String := "Open";
      Initial_Directory : in String := ".";
      Default_Extension : in String := "";
      Change_Directory  : in Boolean := True);

   -- Ask user for filename to open
   -- File_Types should look like :
   --   { "Tcl_Files" { .tcl .tk } }
   --   { "All Files" * }
   procedure Open_Dialog(Interp : Tcl.Tcl_Interp;
      File_Types : in String;
      Filename   : out String;
      File_Last  : out Natural;
      Directory  : out String;
      Dir_Last   : out Natural;
      Title      : in String := "Open";
      Initial_Directory : in String := ".";
      Default_Extension : in String := "";
      Change_Directory  : in Boolean := True);

   -- Ask user for filename to Save
   -- File_Types should look like :
   --   { "Tcl_Files" { .tcl .tk } }
   --   { "All Files" * }
   procedure Save_Dialog(Interp : Tcl.Tcl_Interp;
      File_Types : in String;
      Filename   : out String;
      File_Last  : out Natural;
      Title      : in String := "Save As";
      Initial_Directory : in String := ".";
      Default_Extension : in String := "";
      Change_Directory  : in Boolean := True);

   -- Ask user for filename to Save
   -- File_Types should look like :
   --   { "Tcl_Files" { .tcl .tk } }
   --   { "All Files" * }
   procedure Save_Dialog(Interp : Tcl.Tcl_Interp;
      File_Types : in String;
      Filename   : out String;
      File_Last  : out Natural;
      Directory  : out String;
      Dir_Last   : out Natural;
      Title      : in String := "Save As";
      Initial_Directory : in String := ".";
      Default_Extension : in String := "";
      Change_Directory  : in Boolean := True);
end Common_Dialogs;